@@ -21,21 +21,24 @@
 """Misc plugin."""
 
 
-import os
 import gettext
-_ = lambda m: gettext.dgettext(message=m, domain='ovirt-host-deploy')
+import os
 
 
 from otopi import constants as otopicons
-from otopi import util
 from otopi import context
 from otopi import plugin
+from otopi import util
 
 
 from ovirt_host_deploy import config
 from ovirt_host_deploy import constants as odeploycons
 
 
+def _(m):
+    return gettext.dgettext(message=m, domain='ovirt-host-deploy')
+
+
 @util.export
 class Plugin(plugin.PluginBase):
     """Misc plugin."""
@@ -94,12 +97,6 @@ class Plugin(plugin.PluginBase):
             odeploycons.CoreEnv.FORCE_REBOOT,
             False
         )
-        self.environment[
-            odeploycons.CoreEnv.INSTALL_INCOMPLETE
-        ] = False
-        self.environment[
-            odeploycons.CoreEnv.INSTALL_INCOMPLETE_REASONS
-        ] = []
 
         self.logger.debug(
             'ovirt-host-deploy interface version %s' % (
