@@ -24,24 +24,22 @@
 from otopi import util
 
 
-from . import vdsmid
-from . import pki
-from . import hardware
-from . import software
-from . import packages
-from . import config
 from . import bridge
+from . import config
+from . import hardware
+from . import packages
+from . import software
+from . import vdsmid
 
 
 @util.export
 def createPlugins(context):
-    vdsmid.Plugin(context=context)
-    pki.Plugin(context=context)
-    hardware.Plugin(context=context)
-    software.Plugin(context=context)
-    packages.Plugin(context=context)
-    config.Plugin(context=context)
     bridge.Plugin(context=context)
+    config.Plugin(context=context)
+    hardware.Plugin(context=context)
+    packages.Plugin(context=context)
+    software.Plugin(context=context)
+    vdsmid.Plugin(context=context)
 
 
 # vim: expandtab tabstop=4 shiftwidth=4
